import os
import re
import subprocess
import sys

if len(sys.argv) < 4:
  print(f'Usage: {sys.argv[0]} <filename> <mime-type> <converter> [<extra-util>]')
  sys.exit(1)

filename = sys.argv[1]
mimetype = sys.argv[2]
converter = sys.argv[3]
extra = sys.argv[4] if len(sys.argv) >= 5 else None
basename = os.path.basename(converter)

if basename[:6] == 'abydos':
  args = [converter, filename, mimetype, '.']
elif basename == 'convert':
  args = [converter, filename, os.path.basename(filename)+'.png']
elif basename == 'deark':
  args = [converter, '-q', filename, '-o', os.path.basename(filename)]
elif basename == 'ffmpeg':
  args = [extra, '-v', 'error', '-count_frames', '-select_streams', 'v:0',
          '-show_entries', 'stream=nb_read_frames', '-of', 'csv=p=0', filename]
  ret = subprocess.run(args, capture_output=True, text=True)
  frames = ret.stdout.strip()
  if frames.isnumeric() and int(frames) > 1:
    ext = '.webp'
  else:
    ext = '.png'
  args = [converter, '-y', '-i', filename, os.path.basename(filename)+ext]
else:
  print(f'Unknown converer: {os.path.basename(converter)}', file=sys.stderr)
  sys.exit(2)

before = os.path.getmtime('.')
print(f'Running {args}')
ret = subprocess.run(args, capture_output=True, text=True)
if ret.returncode != 0:
  print(ret.stderr, file=sys.stdout)
  sys.exit(ret.returncode)

files = [f for f in os.listdir('.') if os.path.isfile(f) and os.path.getctime(f) > before]
if not files:
  print(f'No output file was created', file=sys.stdout)
  sys.exit(3)
#print(f'Created files: {files}', file=sys.stderr)

regex = '^' + re.escape(os.path.basename(filename)) + '([-\\.][0-9]+.*)?\\.([^\.]+)$'
for f in files:
  print(f'testing {f}')
  m = re.match(regex, f)
  if m:
    print(m, m.group(2), file=sys.stderr)
    if m.group(2) in ['bmp', 'html', 'ico', 'jpg', 'pcx', 'png', 'qtif', 'svg', 'webp']:
      break
else:
  print(f'No valid output file ({", ".join(files)})', file=sys.stderr)
  sys.exit(4)

sys.exit(0)
