import os
import re
import subprocess
import sys

if len(sys.argv) < 4:
  print(f'Usage: {sys.argv[0]} <filename> <identifier> <mime-type> [<mime-type> ...]', file=sys.stderr)
  sys.exit(1)

filename = sys.argv[1]
identifier = sys.argv[2]
mimetypes = sys.argv[3:]
basename = os.path.basename(identifier)

if basename == 'file':
  args = [identifier, '--mime', filename]
  regex = '\s(.*/.*);\s'
elif basename == 'xdg-mime':
  args = [identifier, 'query', 'filetype', filename]
  regex = '(.*/.*)\s'
else:
  print(f'Unknown identifier: {os.path.basename(identifier)}', file=sys.stderr)
  sys.exit(2)

ret = subprocess.run(args, capture_output=True, text=True)
if ret.returncode != 0:
  print(ret.stderr, file=sys.stdout)
  sys.exit(ret.returncode)
mimetype = re.findall(regex, ret.stdout)

if len(mimetype) < 1:
  print(f'No mime type')
  sys.exit(3)

if not mimetype[0] in mimetypes:
  print(f'The mime type {mimetype[0]} is not among the expected mime types: {", ".join(mimetypes)}', file=sys.stderr)
  sys.exit(4)

sys.exit(0)

